.. wanga documentation master file, created by
   sphinx-quickstart on Mon Jun 24 20:58:25 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to wanga's documentation!
=================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
